@@ -1,6 +1,7 @@
 import os
 from importlib import resources
 from jinja2 import Environment, FileSystemLoader, select_autoescape
+from core import multiply
 
 def get_template_env():
     """Obtiene un entorno de Jinja2 que carga templates desde el paquete turbopdf."""
@@ -12,6 +13,7 @@ def get_template_env():
                 loader=FileSystemLoader(str(templates_dir)),
                 autoescape=select_autoescape()
             )
+            env.filters['multiply'] = multiply
             return env
     
     # Fallback: modo desarrollo
@@ -21,6 +23,7 @@ def get_template_env():
         loader=FileSystemLoader(templates_dir),
         autoescape=select_autoescape()
     )
+    env.filters['multiply'] = multiply
     return env
 
 def render_template(template_name, context):
